==> nzbget-0.1.1.tar.gz: nzbget-0.1.1/global.cpp <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.3 $
 * $Date: 2004/03/30 12:21:03 $
 *
 */


#include "Frontend.h"
#include "global.h"
#include "config.h"

#include <stdarg.h>


void debug(char* msg, ...)
{
#ifdef DEBUG
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

  Frontend::getInstance()->frontendDebug(tmp2);
#endif
}

void error(char* msg, ...)
{
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

  Frontend::getInstance()->frontendError(tmp2);
}

void warn(char* msg, ...)
{
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

  Frontend::getInstance()->frontendWarn(tmp2);
}

void info(char* msg, ...)
{
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

  Frontend::getInstance()->frontendInfo(tmp2);
}

/* #ifdef DEBUG */
/* #define debug(args...)   Frontend::getInstance()->frontendDebug(args) */
/* #else */
/* #define debug(args...)   do { } while(0) */
/* #endif */

/* #define error(args...)   Frontend::getInstance()->frontendError(args) */
/* #define warn(args...)    Frontend::getInstance()->frontendWarn(args) */
/* #define info(args...)    Frontend::getInstance()->frontendInfo(args) */

==> nzbget-0.2.0.tar.gz: nzbget-0.2.0/global.cpp <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.6 $
 * $Date: 2004/08/10 19:04:35 $
 *
 */


#include "Frontend.h"
#include "Options.h"
#include "global.h"
#include "config.h"

#include <stdarg.h>

// Variables
Frontend* frontend		= NULL;
Options* options		= NULL;
char* g_szLogFileName	= NULL;
bool g_bUseLog			= false;
int g_iIPCMessageId		= 0;
bool g_bPause			= false;
bool g_bQuit			= false;
float g_fDownloadRate	= -1.0f;
int g_iProgramPID		= 0;

#ifdef DEBUG
void debug(char* msg, ...)
{
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

  if( frontend )
  {
      frontend->frontendDebug(tmp2);
  }
  else
  {
      printf( "%s\n", tmp2 );
  }
}
#endif

void error(char* msg, ...)
{
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

	if( frontend )
  		frontend->frontendError(tmp2);
	else
		printf( "%s\n", tmp2 );
}

void warn(char* msg, ...)
{
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

  frontend->frontendWarn(tmp2);
}

void info(char* msg, ...)
{
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

  frontend->frontendInfo(tmp2);
}

void abort(char* msg, ...)
{
  char tmp2[1024];

  va_list ap;
  va_start(ap, msg);
  vsnprintf(tmp2, 1024, msg, ap);
  va_end(ap);

  printf("%s", tmp2);
  exit(-1);
}

/* #ifdef DEBUG */
/* #define debug(args...)   Frontend::getInstance()->frontendDebug(args) */
/* #else */
/* #define debug(args...)   do { } while(0) */
/* #endif */

/* #define error(args...)   Frontend::getInstance()->frontendError(args) */
/* #define warn(args...)    Frontend::getInstance()->frontendWarn(args) */
/* #define info(args...)    Frontend::getInstance()->frontendInfo(args) */
